==> fantacalciobazar_0.3.tar.gz: fantacalciobazar/tab_calciatori.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

include("dati/head.php");

include("controlla_pass.php");
if ($pass_errata != "SI") {


$calciatori = file("dati/calciatori.txt");
$num_calciatori = count($calciatori);

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"#b9ccd4\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("
","",$numero);
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("
","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("
","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";

if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td><a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a></td>
</tr>";
} # fine if ($ruolo == $ruolo_guarda or ...)

} # fine for $num1
echo "</table>";

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";

} # fine if ($pass_errata != "SI")

include("dati/foot.php");
?>

==> fantacalciobazar_0.4.tar.gz: fantacalciobazar/tab_calciatori.php <==
<?php

##################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################


include("controlla_pass.php");
include("$percorso_cartella_dati/head.php");
if ($pass_errata != "SI") {



if ($sfondo_tab == "") $sfondo_tab = "#b9ccd4";

$calciatori = file("$percorso_cartella_dati/calciatori.txt");
$num_calciatori = count($calciatori);

echo "<table width=3 border=3 cellspacing=2 cellpadding=5 align=\"center\" bgcolor=\"$sfondo_tab\">
<tr><td>Num.</td>
<td>_____________Nome_____________</td>
<td><font size=-2>Ruolo</font></td>
<td>&nbsp;</td></tr>";

for ($num1 = 0 ; $num1 < $num_calciatori ; $num1++) {

$dati_calciatore = explode($separatore_campi_file_calciatori, $calciatori[$num1]);
$numero = $dati_calciatore[($num_colonna_numcalciatore_file_calciatori-1)];
$numero = ereg_replace("
","",$numero);
$nome = $dati_calciatore[($num_colonna_nome_file_calciatori-1)];
$nome = ereg_replace("
","",$nome);
$nome = ereg_replace("\"","",$nome);
$ruolo = $dati_calciatore[($num_colonna_ruolo_file_calciatori-1)];
$ruolo = ereg_replace("
","",$ruolo);
if ($ruolo == $simbolo_portiere_file_calciatori) $ruolo = "P";
if ($ruolo == $simbolo_difensore_file_calciatori) $ruolo = "D";
if ($ruolo == $simbolo_centrocampista_file_calciatori) $ruolo = "C";
if ($ruolo == $simbolo_attaccante_file_calciatori) $ruolo = "A";

if ($ruolo == $ruolo_guarda or $ruolo_guarda == "tutti") {
echo"<tr><td>$numero</td>
<td>$nome</td>
<td>$ruolo</td>
<td><a href=\"offerta.php?num_calciatore=$numero&nome_utente=$nome_utente&pass_fornita=$pass_fornita\">offri</a></td>
</tr>";
} # fine if ($ruolo == $ruolo_guarda or ...)

} # fine for $num1
echo "</table>";

echo "<center><form method=\"post\" action=\"mercato.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"submit\" name=\"torna_mercato\" value=\"Torna al mercato\">
</form></center>";

} # fine if ($pass_errata != "SI")

include("$percorso_cartella_dati/foot.php");
?>
